@@ -1,16 +1,20 @@
 #pragma once
 
+#include "location.hh"
 #include <cstddef>
 #include <cstdint>
 #include <gmpxx.h>
 #include <iostream>
-#include "location.hh"
 #include <memory>
 #include <rumur/Node.h>
 #include <rumur/Ptr.h>
 #include <string>
 #include <vector>
 
+#ifndef RUMUR_API_WITH_RTTI
+#define RUMUR_API_WITH_RTTI __attribute__((visibility("default")))
+#endif
+
 namespace rumur {
 
 // Forward declarations to avoid a circular #include
@@ -19,56 +23,59 @@ struct Function;
 struct TypeExpr;
 struct VarDecl;
 
-struct Expr : public Node {
+struct RUMUR_API_WITH_RTTI Expr : public Node {
 
   Expr(const location &loc_);
   virtual ~Expr() = default;
 
   virtual Expr *clone() const = 0;
 
-  // Whether an expression is a compile-time constant
+  /// is this expression a compile-time constant?
   virtual bool constant() const = 0;
 
-  /* The type of this expression. A nullptr indicates the type is equivalent
-   * to a numeric literal; that is, an unbounded range.
-   */
+  /// The type of this expression. Never returns `nullptr`.
   virtual Ptr<TypeExpr> type() const = 0;
 
-  // If this expression is of boolean type.
+  /// is this expression of boolean type?
   bool is_boolean() const;
 
+  /// Evaluate this expression. This will throw `Error` if `constant()` is not
+  /// true.
   virtual mpz_class constant_fold() const = 0;
 
-  // Is this value valid to use on the LHS of an assignment?
+  /// is this value valid to use on the LHS of an assignment?
   virtual bool is_lvalue() const;
 
-  /* Is this value a constant (cannot be modified)? It only makes sense to ask
-   * this of expressions for which is_lvalue() returns true. For non-lvalues,
-   * this is always true.
-   */
+  /// Is this value a constant (cannot be modified)? It only makes sense to ask
+  /// this of expressions for which is_lvalue() returns true. For non-lvalues,
+  /// this is always true.
   virtual bool is_readonly() const;
 
-  // Get a string representation of this expression
+  /// get a string representation of this expression
   virtual std::string to_string() const = 0;
 
-  // is this expression the boolean literal “true”?
+  /// is this expression the boolean literal “true”?
   virtual bool is_literal_true() const;
 
-  // is this expression the boolean literal “false”?
+  /// is this expression the boolean literal “false”?
   virtual bool is_literal_false() const;
 
-  // is this expression side-effect free?
+  /// is this expression side-effect free?
   virtual bool is_pure() const = 0;
+
+protected:
+  Expr(const Expr &) = default;
+  Expr &operator=(const Expr &) = default;
 };
 
-struct Ternary : public Expr {
+struct RUMUR_API_WITH_RTTI Ternary : public Expr {
 
   Ptr<Expr> cond;
   Ptr<Expr> lhs;
   Ptr<Expr> rhs;
 
-  Ternary(const Ptr<Expr> &cond_, const Ptr<Expr> &lhs_,
-    const Ptr<Expr> &rhs_, const location &loc_);
+  Ternary(const Ptr<Expr> &cond_, const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
+          const location &loc_);
   virtual ~Ternary() = default;
   Ternary *clone() const final;
 
@@ -87,34 +94,42 @@ struct Ternary : public Expr {
    */
 };
 
-struct BinaryExpr : public Expr {
+struct RUMUR_API_WITH_RTTI BinaryExpr : public Expr {
 
   Ptr<Expr> lhs;
   Ptr<Expr> rhs;
 
   BinaryExpr(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
-    const location &loc_);
+             const location &loc_);
   virtual ~BinaryExpr() = default;
 
   BinaryExpr *clone() const override = 0;
   bool constant() const final;
   bool is_pure() const final;
+
+protected:
+  BinaryExpr(const BinaryExpr &) = default;
+  BinaryExpr &operator=(const BinaryExpr &) = default;
 };
 
-struct BooleanBinaryExpr : public BinaryExpr {
+struct RUMUR_API_WITH_RTTI BooleanBinaryExpr : public BinaryExpr {
 
   BooleanBinaryExpr(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
-    const location &loc_);
+                    const location &loc_);
   BooleanBinaryExpr() = delete;
 
   Ptr<TypeExpr> type() const final;
   void validate() const final;
+
+protected:
+  BooleanBinaryExpr(const BooleanBinaryExpr &) = default;
+  BooleanBinaryExpr &operator=(const BooleanBinaryExpr &) = default;
 };
 
-struct Implication : public BooleanBinaryExpr {
+struct RUMUR_API_WITH_RTTI Implication : public BooleanBinaryExpr {
 
   Implication(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
-    const location &loc_);
+              const location &loc_);
   Implication *clone() const final;
   virtual ~Implication() = default;
 
@@ -125,8 +140,8 @@ struct Implication : public BooleanBinaryExpr {
   std::string to_string() const final;
 };
 
-// logical OR
-struct Or : public BooleanBinaryExpr {
+/// logical OR
+struct RUMUR_API_WITH_RTTI Or : public BooleanBinaryExpr {
 
   Or(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Or() = default;
@@ -139,8 +154,8 @@ struct Or : public BooleanBinaryExpr {
   std::string to_string() const final;
 };
 
-// logical AND
-struct And : public BooleanBinaryExpr {
+/// logical AND
+struct RUMUR_API_WITH_RTTI And : public BooleanBinaryExpr {
 
   And(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~And() = default;
@@ -153,12 +168,13 @@ struct And : public BooleanBinaryExpr {
   std::string to_string() const final;
 };
 
-// An 'x & y' expression where a decision has not yet been made as to whether
-// the '&' is a logical AND or a bitwise AND. These nodes can only occur in the
-// AST prior to symbol resolution.
-struct AmbiguousAmp : public BinaryExpr {
+/// An 'x & y' expression where a decision has not yet been made as to whether
+/// the '&' is a logical AND or a bitwise AND. These nodes can only occur in the
+/// AST prior to symbol resolution.
+struct RUMUR_API_WITH_RTTI AmbiguousAmp : public BinaryExpr {
 
-  AmbiguousAmp(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
+  AmbiguousAmp(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
+               const location &loc_);
   virtual ~AmbiguousAmp() = default;
   AmbiguousAmp *clone() const final;
 
@@ -170,13 +186,13 @@ struct AmbiguousAmp : public BinaryExpr {
   std::string to_string() const final;
 };
 
-// An 'x | y' expression where a decision has not yet been made as to whether
-// the '|' is a logical OR or a bitwise OR. These nodes can only occur in the
-// AST prior to symbol resolution.
-struct AmbiguousPipe : public BinaryExpr {
+/// An 'x | y' expression where a decision has not yet been made as to whether
+/// the '|' is a logical OR or a bitwise OR. These nodes can only occur in the
+/// AST prior to symbol resolution.
+struct RUMUR_API_WITH_RTTI AmbiguousPipe : public BinaryExpr {
 
   AmbiguousPipe(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
-    const location &loc_);
+                const location &loc_);
   virtual ~AmbiguousPipe() = default;
   AmbiguousPipe *clone() const final;
 
@@ -188,7 +204,7 @@ struct AmbiguousPipe : public BinaryExpr {
   std::string to_string() const final;
 };
 
-struct UnaryExpr : public Expr {
+struct RUMUR_API_WITH_RTTI UnaryExpr : public Expr {
 
   Ptr<Expr> rhs;
 
@@ -198,9 +214,13 @@ struct UnaryExpr : public Expr {
 
   bool constant() const override;
   bool is_pure() const final;
+
+protected:
+  UnaryExpr(const UnaryExpr &) = default;
+  UnaryExpr &operator=(const UnaryExpr &) = default;
 };
 
-struct Not : public UnaryExpr {
+struct RUMUR_API_WITH_RTTI Not : public UnaryExpr {
 
   Not(const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Not() = default;
@@ -215,15 +235,19 @@ struct Not : public UnaryExpr {
   std::string to_string() const final;
 };
 
-struct ComparisonBinaryExpr : public BinaryExpr {
+struct RUMUR_API_WITH_RTTI ComparisonBinaryExpr : public BinaryExpr {
 
   ComparisonBinaryExpr(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
-    const location &loc_);
+                       const location &loc_);
 
   void validate() const final;
+
+protected:
+  ComparisonBinaryExpr(const ComparisonBinaryExpr &) = default;
+  ComparisonBinaryExpr &operator=(const ComparisonBinaryExpr &) = default;
 };
 
-struct Lt : public ComparisonBinaryExpr {
+struct RUMUR_API_WITH_RTTI Lt : public ComparisonBinaryExpr {
 
   Lt(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Lt() = default;
@@ -237,7 +261,7 @@ struct Lt : public ComparisonBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Leq : public ComparisonBinaryExpr {
+struct RUMUR_API_WITH_RTTI Leq : public ComparisonBinaryExpr {
 
   Leq(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Leq() = default;
@@ -251,7 +275,7 @@ struct Leq : public ComparisonBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Gt : public ComparisonBinaryExpr {
+struct RUMUR_API_WITH_RTTI Gt : public ComparisonBinaryExpr {
 
   Gt(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Gt() = default;
@@ -265,7 +289,7 @@ struct Gt : public ComparisonBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Geq : public ComparisonBinaryExpr {
+struct RUMUR_API_WITH_RTTI Geq : public ComparisonBinaryExpr {
 
   Geq(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Geq() = default;
@@ -279,15 +303,19 @@ struct Geq : public ComparisonBinaryExpr {
   std::string to_string() const final;
 };
 
-struct EquatableBinaryExpr : public BinaryExpr {
+struct RUMUR_API_WITH_RTTI EquatableBinaryExpr : public BinaryExpr {
 
   EquatableBinaryExpr(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
-    const location &loc_);
+                      const location &loc_);
 
   void validate() const final;
+
+protected:
+  EquatableBinaryExpr(const EquatableBinaryExpr &) = default;
+  EquatableBinaryExpr &operator=(const EquatableBinaryExpr &) = default;
 };
 
-struct Eq : public EquatableBinaryExpr {
+struct RUMUR_API_WITH_RTTI Eq : public EquatableBinaryExpr {
 
   Eq(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Eq() = default;
@@ -301,7 +329,7 @@ struct Eq : public EquatableBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Neq : public EquatableBinaryExpr {
+struct RUMUR_API_WITH_RTTI Neq : public EquatableBinaryExpr {
 
   Neq(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Neq() = default;
@@ -315,16 +343,20 @@ struct Neq : public EquatableBinaryExpr {
   std::string to_string() const final;
 };
 
-struct ArithmeticBinaryExpr : public BinaryExpr {
+struct RUMUR_API_WITH_RTTI ArithmeticBinaryExpr : public BinaryExpr {
 
   ArithmeticBinaryExpr(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_,
-    const location &loc_);
+                       const location &loc_);
 
   Ptr<TypeExpr> type() const final;
   void validate() const final;
+
+protected:
+  ArithmeticBinaryExpr(const ArithmeticBinaryExpr &) = default;
+  ArithmeticBinaryExpr &operator=(const ArithmeticBinaryExpr &) = default;
 };
 
-struct Add : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Add : public ArithmeticBinaryExpr {
 
   Add(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Add() = default;
@@ -337,7 +369,7 @@ struct Add : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Sub : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Sub : public ArithmeticBinaryExpr {
 
   Sub(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Sub() = default;
@@ -350,7 +382,7 @@ struct Sub : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Negative : public UnaryExpr {
+struct RUMUR_API_WITH_RTTI Negative : public UnaryExpr {
 
   Negative(const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Negative() = default;
@@ -365,7 +397,7 @@ struct Negative : public UnaryExpr {
   std::string to_string() const final;
 };
 
-struct Bnot : public UnaryExpr {
+struct RUMUR_API_WITH_RTTI Bnot : public UnaryExpr {
 
   Bnot(const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Bnot() = default;
@@ -380,7 +412,7 @@ struct Bnot : public UnaryExpr {
   std::string to_string() const final;
 };
 
-struct Mul : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Mul : public ArithmeticBinaryExpr {
 
   Mul(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Mul() = default;
@@ -393,7 +425,7 @@ struct Mul : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Div : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Div : public ArithmeticBinaryExpr {
 
   Div(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Div() = default;
@@ -406,7 +438,7 @@ struct Div : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Mod : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Mod : public ArithmeticBinaryExpr {
 
   Mod(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Mod() = default;
@@ -419,7 +451,7 @@ struct Mod : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Lsh : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Lsh : public ArithmeticBinaryExpr {
 
   Lsh(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Lsh() = default;
@@ -432,7 +464,7 @@ struct Lsh : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Rsh : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Rsh : public ArithmeticBinaryExpr {
 
   Rsh(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Rsh() = default;
@@ -445,8 +477,8 @@ struct Rsh : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-// bitwise AND
-struct Band : public ArithmeticBinaryExpr {
+/// bitwise AND
+struct RUMUR_API_WITH_RTTI Band : public ArithmeticBinaryExpr {
 
   Band(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Band() = default;
@@ -459,8 +491,8 @@ struct Band : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-// bitwise OR
-struct Bor : public ArithmeticBinaryExpr {
+/// bitwise OR
+struct RUMUR_API_WITH_RTTI Bor : public ArithmeticBinaryExpr {
 
   Bor(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Bor() = default;
@@ -473,7 +505,7 @@ struct Bor : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-struct Xor : public ArithmeticBinaryExpr {
+struct RUMUR_API_WITH_RTTI Xor : public ArithmeticBinaryExpr {
 
   Xor(const Ptr<Expr> &lhs_, const Ptr<Expr> &rhs_, const location &loc_);
   virtual ~Xor() = default;
@@ -486,14 +518,13 @@ struct Xor : public ArithmeticBinaryExpr {
   std::string to_string() const final;
 };
 
-
-struct ExprID : public Expr {
+struct RUMUR_API_WITH_RTTI ExprID : public Expr {
 
   std::string id;
   Ptr<ExprDecl> value;
 
   ExprID(const std::string &id_, const Ptr<ExprDecl> &value_,
-    const location &loc_);
+         const location &loc_);
   virtual ~ExprID() = default;
   ExprID *clone() const final;
 
@@ -512,13 +543,13 @@ struct ExprID : public Expr {
   bool is_pure() const final;
 };
 
-struct Field : public Expr {
+struct RUMUR_API_WITH_RTTI Field : public Expr {
 
   Ptr<Expr> record;
   std::string field;
 
   Field(const Ptr<Expr> &record_, const std::string &field_,
-    const location &loc_);
+        const location &loc_);
   virtual ~Field() = default;
   Field *clone() const final;
 
@@ -535,13 +566,13 @@ struct Field : public Expr {
   bool is_pure() const final;
 };
 
-struct Element : public Expr {
+struct RUMUR_API_WITH_RTTI Element : public Expr {
 
   Ptr<Expr> array;
   Ptr<Expr> index;
 
   Element(const Ptr<Expr> &array_, const Ptr<Expr> &index_,
-    const location &loc_);
+          const location &loc_);
   virtual ~Element() = default;
   Element *clone() const final;
 
@@ -558,17 +589,17 @@ struct Element : public Expr {
   bool is_pure() const final;
 };
 
-struct FunctionCall : public Expr {
+struct RUMUR_API_WITH_RTTI FunctionCall : public Expr {
 
   std::string name;
   Ptr<Function> function;
   std::vector<Ptr<Expr>> arguments;
 
-  // Whether this is a child of a ProcedureCall
+  /// whether this is a child of a `ProcedureCall`
   bool within_procedure_call = false;
 
   FunctionCall(const std::string &name_,
-    const std::vector<Ptr<Expr>> &arguments_, const location &loc_);
+               const std::vector<Ptr<Expr>> &arguments_, const location &loc_);
   virtual ~FunctionCall() = default;
   FunctionCall *clone() const final;
 
@@ -583,11 +614,11 @@ struct FunctionCall : public Expr {
   bool is_pure() const final;
 };
 
-struct Quantifier : public Node {
+struct RUMUR_API_WITH_RTTI Quantifier : public Node {
 
   std::string name;
 
-  // If this is != nullptr, the from/to/step will be nullptr
+  // if this is != nullptr, the from/to/step will be nullptr
   Ptr<TypeExpr> type;
 
   Ptr<Expr> from;
@@ -597,12 +628,12 @@ struct Quantifier : public Node {
   Ptr<VarDecl> decl;
 
   Quantifier(const std::string &name_, const Ptr<TypeExpr> &type_,
-    const location &loc);
+             const location &loc);
   Quantifier(const std::string &name_, const Ptr<Expr> &from_,
-    const Ptr<Expr> &to_, const location &loc_);
+             const Ptr<Expr> &to_, const location &loc_);
   Quantifier(const std::string &name_, const Ptr<Expr> &from_,
-    const Ptr<Expr> &to_, const Ptr<Expr> &step_,
-    const location &loc_);
+             const Ptr<Expr> &to_, const Ptr<Expr> &step_,
+             const location &loc_);
   virtual ~Quantifier() = default;
   Quantifier *clone() const final;
   void validate() const final;
@@ -611,28 +642,27 @@ struct Quantifier : public Node {
   void visit(BaseTraversal &visitor) final;
   void visit(ConstBaseTraversal &visitor) const final;
 
-  // whether the quantifier's range can be constant folded
+  /// whether the quantifier’s range can be constant folded
   bool constant() const;
 
-  /* number of entries in this quantifier's range (only valid when constant()
-   * returns true)
-   */
+  /// number of entries in this quantifier’s range (only valid when `constant()`
+  /// returns `true`)
   mpz_class count() const;
 
-  // get the lower bound of this quantified expression as a C expression
+  /// get the lower bound of this quantified expression as a C expression
   std::string lower_bound() const;
 
-  // is this side-effect free?
+  /// is this side-effect free?
   bool is_pure() const;
 };
 
-struct Exists : public Expr {
+struct RUMUR_API_WITH_RTTI Exists : public Expr {
 
   Quantifier quantifier;
   Ptr<Expr> expr;
 
   Exists(const Quantifier &quantifier_, const Ptr<Expr> &expr_,
-    const location &loc_);
+         const location &loc_);
   virtual ~Exists() = default;
   Exists *clone() const final;
 
@@ -647,13 +677,13 @@ struct Exists : public Expr {
   bool is_pure() const final;
 };
 
-struct Forall : public Expr {
+struct RUMUR_API_WITH_RTTI Forall : public Expr {
 
   Quantifier quantifier;
   Ptr<Expr> expr;
 
   Forall(const Quantifier &quantifier_, const Ptr<Expr> &expr_,
-    const location &loc_);
+         const location &loc_);
   virtual ~Forall() = default;
   Forall *clone() const final;
 
@@ -668,7 +698,7 @@ struct Forall : public Expr {
   bool is_pure() const final;
 };
 
-struct IsUndefined : public UnaryExpr {
+struct RUMUR_API_WITH_RTTI IsUndefined : public UnaryExpr {
 
   IsUndefined(const Ptr<Expr> &expr_, const location &loc_);
   virtual ~IsUndefined() = default;
@@ -684,4 +714,4 @@ struct IsUndefined : public UnaryExpr {
   std::string to_string() const final;
 };
 
-}
+} // namespace rumur
