@@ -5,9 +5,13 @@
 #include <rumur/Model.h>
 #include <rumur/Ptr.h>
 
+#ifndef RUMUR_API
+#define RUMUR_API __attribute__((visibility("default")))
+#endif
+
 namespace rumur {
 
 // Parse in a model from an input stream. Throws Errors on parsing errors.
-Ptr<Model> parse(std::istream &input);
+RUMUR_API Ptr<Model> parse(std::istream &input);
 
-}
+} // namespace rumur
