@@ -3,11 +3,15 @@
 #include <cstddef>
 #include <rumur/Model.h>
 
+#ifndef RUMUR_API
+#define RUMUR_API __attribute__((visibility("default")))
+#endif
+
 namespace rumur {
 
 /* Resolve symbolic references (rumur::ExprIDs and rumur::TypeExprIDs) within a
  * model. Throws rumur::Error if this process fails.
  */
-void resolve_symbols(Model &m);
+RUMUR_API void resolve_symbols(Model &m);
 
-}
+} // namespace rumur
