@@ -1,18 +1,18 @@
+#include "location.hh"
+#include "parser.yy.hh"
 #include <cassert>
 #include <cstddef>
 #include <iostream>
-#include "location.hh"
-#include "parser.yy.hh"
 #include <rumur/Decl.h>
-#include <rumur/except.h>
 #include <rumur/Model.h>
-#include <rumur/parse.h>
 #include <rumur/Ptr.h>
+#include <rumur/except.h>
+#include <rumur/parse.h>
 #include <rumur/scanner.h>
 
-namespace rumur {
+using namespace rumur;
 
-Ptr<Model> parse(std::istream &input) {
+Ptr<Model> rumur::parse(std::istream &input) {
 
   // Setup the parser
   scanner s(&input);
@@ -26,5 +26,3 @@ Ptr<Model> parse(std::istream &input) {
 
   return m;
 }
-
-}
