@@ -3,10 +3,10 @@
 # Download and install Macports. For use in CI.
 
 # Version of Macports to install
-VERSION=2.6.4
+VERSION=2.7.2
 
 if [ "$(uname)" != "Darwin" ]; then
-  printf 'this script is only intended to run on macOS\n'
+  printf 'this script is only intended to run on macOS\n' >&2
   exit 1
 fi
 
