@@ -1,9 +1,9 @@
-#include <cstddef>
 #include "../../common/escape.h"
 #include "generate.h"
+#include "utils.h"
+#include <cstddef>
 #include <iostream>
 #include <rumur/rumur.h>
-#include "utils.h"
 
 using namespace rumur;
 
@@ -11,12 +11,12 @@ namespace {
 
 class CoverAccumulator : public ConstTraversal {
 
- private:
+private:
   std::ostream *out;
   size_t count = 0;
 
- public:
-  CoverAccumulator(std::ostream &o): out(&o) { }
+public:
+  CoverAccumulator(std::ostream &o) : out(&o) {}
 
   void visit_property(const Property &n) final {
     if (n.category == Property::COVER) {
@@ -25,18 +25,16 @@ class CoverAccumulator : public ConstTraversal {
     }
   }
 
-  size_t get_count() const {
-    return count;
-  }
+  size_t get_count() const { return count; }
 };
 
 class MessageGenerator : public ConstTraversal {
 
- private:
+private:
   std::ostream *out;
 
- public:
-  MessageGenerator(std::ostream &o): out(&o) { }
+public:
+  MessageGenerator(std::ostream &o) : out(&o) {}
 
   void visit_propertyrule(const PropertyRule &n) final {
     if (n.property.category == Property::COVER) {
@@ -61,7 +59,7 @@ class MessageGenerator : public ConstTraversal {
   }
 };
 
-}
+} // namespace
 
 void generate_cover_array(std::ostream &out, const Model &model) {
   out << "enum {\n";
@@ -69,10 +67,10 @@ void generate_cover_array(std::ostream &out, const Model &model) {
   CoverAccumulator ca(out);
   ca.dispatch(model);
 
-  out
-    << "  /* Dummy entry in case the above generated list is empty to avoid an empty enum. */\n"
-    << "  COVER_INVALID = -1,\n"
-    << "};\n\n";
+  out << "  /* Dummy entry in case the above generated list is empty to avoid "
+         "an empty enum. */\n"
+      << "  COVER_INVALID = -1,\n"
+      << "};\n\n";
 
   out << "static const char *COVER_MESSAGES[] = {\n";
   MessageGenerator mg(out);
