@@ -1,6 +1,6 @@
 -- rumur_flags: ['--deadlock-detection', 'off', '--threads', '1']
 -- checker_exit_code: 1
--- checker_output: None if self.xml else re.compile(r'(?!(.|\n)*\b(s\[D\]:\s*3)\b(.|\n)*\b\2\b)')
+-- checker_output: None if xml else re.compile(r'(?!(.|\n)*\b(s\[D\]:\s*3)\b(.|\n)*\b\2\b)')
 
 /* This model tests for regression of a bug first observed on commit
  * 7e5654ddb9ad4f3342d3c1b1abef9a3402df5dee. Certain models using enums to index
