@@ -10,12 +10,12 @@ model = pathlib.Path(__file__).parent / 'assume-statement.m'
 assert model.exists()
 
 # use the explicit-semicolons pass to add semi-colons
-print(f'+ murphi2murphi --explicit-semicolons {model}')
+print('+ murphi2murphi --explicit-semicolons {}'.format(model))
 transformed = subprocess.check_output(['murphi2murphi',
-  '--explicit-semicolons', model])
+  '--explicit-semicolons', str(model)])
 decoded = transformed.decode('utf-8', 'replace')
 
-print(f'transformed model:\n{decoded}')
+print('transformed model:\n{}'.format(decoded))
 
 # we should now find the variable definition and both rules in this model are
 # semi-colon terminated
@@ -24,4 +24,6 @@ assert len(re.findall(r'^end;$', decoded, re.MULTILINE)) == 2
 
 # the generated model also should be valid syntax for Rumur
 print('+ rumur --output /dev/null <(transformed model)')
-subprocess.run(['rumur', '--output', os.devnull], check=True, input=transformed)
+p = subprocess.Popen(['rumur', '--output', os.devnull], stdin=subprocess.PIPE)
+p.communicate(transformed)
+assert p.returncode == 0
