@@ -1,5 +1,5 @@
 -- checker_exit_code: 1
--- checker_output: None if self.xml else re.compile(r'^Rule "foo" fired', re.MULTILINE)
+-- checker_output: None if xml else re.compile(r'^Rule "foo" fired', re.MULTILINE)
 
 -- Test that smart quotes can be used to delimit a string. This test case works
 -- by deliberately triggering a model error that should cause a backtrace
